#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://sourceforge.net/projects/symbolica/
# source           : http://mesh.dl.sourceforge.net/sourceforge/symbolica/symbolica-0.8-source.tar.bz2
# data source	   : http://surfnet.dl.sourceforge.net/sourceforge/symbolica/symbolica-0.8-data.tar.gz

# Package name
NAME="symbolica"
# Package version
VERSION="0.8"
# Source code URL
SOURCE="http://mesh.dl.sourceforge.net/sourceforge/symbolica/symbolica-$VERSION-source.tar.bz2"
# Data source URL
DATASOURCE="http://surfnet.dl.sourceforge.net/sourceforge/symbolica/symbolica-$VERSION-data.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="BUILD COPYING INSTALL README README.DEVELOPERS README.LEVELBUILDERS README.TILES"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Symbolica is a rewrite of the c64 puzzle game symbolica.
$NAME:
$NAME: The symbols on the screen represent a numeric value in the order as
$NAME: they are displayed on the right. As you move over a symbol, it is
$NAME: decremented to the next lower symbol or disappears. Your job is to
$NAME: clear the screen and move to the 'E' symbol.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Symbolica
Exec=symbolica
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=symbolica
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION-source.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if the data file is present. If it's not, download it
rm -rf data
if [ -f $NAME-$VERSION-data.tar.gz ]; then
	echo "Data source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $DATASOURCE
fi


# Check to see if an icon is present. If it's not, download it and put it in the right place
if [ -f symbolica.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a symbolica.png $PKG/usr/share/icons/hicolor/48x48/apps

# Unpack source and data
tar xvjf $NAME-$VERSION-source.tar.bz2
tar xvzf $NAME-$VERSION-data.tar.gz

# make and install in temp dir
cd $NAME-$VERSION
sed -i -e 's,CFLAGS=,CFLAGS= -O2 -march=i486 -mtune=i686 ,' Makefile
sed -i -e 's,$(CPP) -o $(TARGET) $(LDFLAGS) $(OBJ) $(GODLIB),$(CPP) -o $(TARGET) $(LDFLAGS) $(OBJ) $(GODLIB) -O2 -march=i486 -mtune=i686,' Makefile
sed -i -e 's,CFLAGS=,CFLAGS= -O2 -march=i486 -mtune=i686 ,' godlib/Makefile
make install
mkdir -p $PKG/usr/share/symbolica
cp -a dist/$NAME-$VERSION/symbolica $PKG/usr/share/symbolica

# Also install the data
mv $CWD/data $PKG/usr/share/symbolica

# Symbolica needs to be started from it's own directory
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/symbolica <<EOF
#!/bin/bash
cd /usr/share/symbolica
./symbolica
EOF
chmod +x $PKG/usr/bin/symbolica

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
